@@ -419,6 +419,33 @@ class MakePatchTestCase(unittest.TestCase):
         new_from_patch = jsonpatch.apply_patch(old, patch)
         self.assertEqual(new, new_from_patch)
 
+    def test_move_from_numeric_to_alpha_dict_key(self):
+        #https://github.com/stefankoegl/python-json-patch/issues/97
+        src = {'13': 'x'}
+        dst = {'A': 'a', 'b': 'x'}
+        patch = jsonpatch.make_patch(src, dst)
+        res = jsonpatch.apply_patch(src, patch)
+        self.assertEqual(res, dst)
+
+    def test_issue90(self):
+        """In JSON 1 is different from True even though in python 1 == True"""
+        src = {'A': 1}
+        dst = {'A': True}
+        patch = jsonpatch.make_patch(src, dst)
+        res = jsonpatch.apply_patch(src, patch)
+        self.assertEqual(res, dst)
+        self.assertIsInstance(res['A'], bool)
+
+    def test_issue103(self):
+        """In JSON 1 is different from 1.0 even though in python 1 == 1.0"""
+        src = {'A': 1}
+        dst = {'A': 1.0}
+        patch = jsonpatch.make_patch(src, dst)
+        res = jsonpatch.apply_patch(src, patch)
+        self.assertEqual(res, dst)
+        self.assertIsInstance(res['A'], float)
+
+
 
 class OptimizationTests(unittest.TestCase):
     def test_use_replace_instead_of_remove_add(self):
@@ -602,6 +629,11 @@ class ConflictTests(unittest.TestCase):
         patch_obj = [ { "op": "replace", "path": "/foo/10", "value": 10} ]
         self.assertRaises(jsonpatch.JsonPatchConflict, jsonpatch.apply_patch, src, patch_obj)
 
+    def test_replace_oob_length(self):
+        src = {"foo": [0, 1]}
+        patch_obj = [ { "op": "replace", "path": "/foo/2", "value": 2} ]
+        self.assertRaises(jsonpatch.JsonPatchConflict, jsonpatch.apply_patch, src, patch_obj)
+
     def test_replace_missing(self):
         src = {"foo": 1}
         patch_obj = [ { "op": "replace", "path": "/bar", "value": 10} ]
